Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(291)

Unified Diff: sdk/lib/_internal/js_runtime/lib/annotations.dart

Issue 1220333003: dart2js: Rename emitters. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/compiler/lib/src/patch_parser.dart ('k') | sdk/lib/_internal/js_runtime/lib/core_patch.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sdk/lib/_internal/js_runtime/lib/annotations.dart
diff --git a/sdk/lib/_internal/js_runtime/lib/annotations.dart b/sdk/lib/_internal/js_runtime/lib/annotations.dart
index 0ade22151b95fae28989cdce2c87d986d9a23743..ee33493fe7c0a35d24832af7f2dd1261058b6dcb 100644
--- a/sdk/lib/_internal/js_runtime/lib/annotations.dart
+++ b/sdk/lib/_internal/js_runtime/lib/annotations.dart
@@ -51,8 +51,8 @@ class _Patch {
/// Annotation that marks the declaration as a patch.
const _Patch patch = const _Patch(null);
-/// Annotation that marks the declaration as a patch for the old emitter.
-const _Patch patch_old = const _Patch('old');
+/// Annotation that marks the declaration as a patch for the full emitter.
+const _Patch patch_full = const _Patch('full');
-/// Annotation that marks the declaration as a patch for the new emitter.
-const _Patch patch_new = const _Patch('new');
+/// Annotation that marks the declaration as a patch for the lazy emitter.
+const _Patch patch_lazy = const _Patch('lazy');
« no previous file with comments | « pkg/compiler/lib/src/patch_parser.dart ('k') | sdk/lib/_internal/js_runtime/lib/core_patch.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698